import http.cookies
import json
import os
import urllib.parse
import traceback
from functools import update_wrapper

def qsp(event):
    if not event:
        return None
    return event.get("queryStringParameters") if event.get("queryStringParameters") else {}

def base_path(event):
    if not event:
        return ""
    event_path = event.get("path","").rstrip("/")
    if event.get("pathParameters") and event["pathParameters"].get("proxy"):
        proxy = event["pathParameters"]["proxy"].rstrip("/")
        event_path = event_path[:-1*len(proxy)].rstrip("/")
    return event_path

def page_path(event):
    if event.get("pathParameters") and event["pathParameters"].get("proxy"):
        return event["pathParameters"]["proxy"].rstrip("/")
    else:
        return ""

def domain(event, prefix="https://"):
    if not event:
        return None
    return (prefix if prefix else "") + event["headers"]["Host"]

def base_url(event, prefix="https://"):
    if not event:
        return None
    return domain(event, prefix=prefix) + base_path(event)

def static_path(event):
    if "STATIC_BUCKET" in os.environ and "STATIC_PATH" in os.environ:
        return "https://s3.amazonaws.com/{STATIC_BUCKET}/{STATIC_PATH}".format(**os.environ)
    if not event:
        return None
    return base_path(event)



from sneks import snekjson as json

def generate_client_from_file(fname):
    return generate_client(json.loadf(fname))

PRIMITIVES = [
    "string", # String
    "float", # floating-point number
    "int", # int
    "boolean", # true/false
    "bytes" # Binary blob, passed as base64
    "undefined", # type is undefined.  In languages like Java that require types, it'll be whatever the generic type is.
    "list", # List of objects.  Elements has a single entry, "Items", indicating the type of the objects contained in the list.
    "map", # Map of keys to values.  Elements has two entries, "Keys" indicating the key type (usually string) and "Values" indicating the value type.
    "object", # Object with any number of key-value pairs.  Difference between this and map is that this has predefined keys corresponding to values of predefined types.  So, this is like a normal object, whereas map is like a dict or java map.  Elements has any number of entries, with the keys giving the names of the attributes and the values giving the types.
]

def generate_client(model):
    datatypes = model.get("DataTypes",{})
    pass
